<?php

namespace Drupal\crowdfunding\Model;

/**
 * @file
 */
class Project extends \EntityDrupalWrapper {

  /**
   * Instancia o projeto, buscando os dados pré-processados
   */
  public function __construct($nid = NULL, $info = array()) {
    parent::__construct('node', $nid, $info);
  }

  public function getTitle() {
    return $this->title->value();
  }

  public function getAuthor() {
    return $this->author->value();
  }

  /**
   * @return array
   */
  public function getRewardOptions($status = NULL) {

    $query = new \EntityFieldQuery();
    $query->entityCondition('entity_type', 'commerce_product')
      ->entityCondition('bundle', 'crowdfunding_reward')
      ->fieldCondition('field_crowdfunding_project_ref', 'target_id', $this->id)
      ->addMetaData('account', user_load(1));
    if (isset($status)) {
      $query->propertyCondition('status', $status);
    }
    $result = $query->execute();

    $rewards = array();
    if (isset($result['commerce_product'])) {
      foreach (array_keys($result['commerce_product']) as $product_id) {
        $rewards[] = new Reward($product_id);
      }
    }
    return $rewards;
  }

  /**
   * Return product_id from the product associated with this project that
   * represents a pledge without reward
   * @return int
   */
  public function getPledgeWithoutRewardProduct() {
    $query = new \EntityFieldQuery();
    $query->entityCondition('entity_type', 'commerce_product')
      ->entityCondition('bundle', 'crowdfunding_no_reward')
      ->fieldCondition('field_crowdfunding_project_ref', 'target_id', $this->getIdentifier())
      ->addMetaData('account', user_load(1));
    $result = $query->execute();

    if (empty($result['commerce_product'])) {
      return \Drupal\crowdfunding\Services\CommerceProductService::createPledgeWithoutRewardForProject(
          $this->getIdentifier(), $this->getTitle()
        )->product_id;
    }
    else {
      return current($result['commerce_product'])->product_id;
    }
  }

}
